==> price_parser_reworkd-0.1.1-py3-none-any.whl: price_parser/parser.py <==
from pydantic import BeforeValidator
from typing import Union, Optional
from typing_extensions import Annotated
from price_parser.type_price import ParserTypePrice


popular_currencies = sorted(
    [
        ("$", "USD"),
        ("€", "EUR"),
        ("¥", "JPY"),
        ("£", "GBP"),
        ("A$", "AUD"),
        ("C$", "CAD"),
        ("CHF", "CHF"),
        ("¥", "CNY"),
        ("kr", "SEK"),
        ("NZ$", "NZD"),
        ("S$", "SGD"),
        ("HK$", "HKD"),
        ("kr", "NOK"),
        ("₩", "KRW"),
        ("₺", "TRY"),
        ("₹", "INR"),
        ("₽", "RUB"),
        ("R$", "BRL"),
        ("R", "ZAR"),
        ("RM", "MYR"),
        ("฿", "THB"),
        ("Rp", "IDR"),
        ("zł", "PLN"),
        ("₱", "PHP"),
        ("Kč", "CZK"),
        ("د.إ", "AED"),
        ("Ft", "HUF"),
        ("₪", "ILS"),
        ("﷼", "SAR"),
    ],
    key=lambda x: len(x[0]),
    reverse=True,
)


class CurrencyParser:
    @staticmethod
    def parse_currency_amount(
        value: Union[str, float, int, None],
    ) -> Union[float, None]:
        return ParserTypePrice.validate_price(value)

    def __call__(
        self, value: Union[str, float, int, None]
    ) -> dict[str, Optional[Union[str, float]]]:
        if isinstance(value, (float, int)):
            return {"currency": None, "currency_symbol": None, "amount": float(value)}
        amount = self.parse_currency_amount(value)
        symbol = None
        currency_name = None
        if amount is not None:
            for sym, curr in popular_currencies:
                if sym in value or curr.lower() in value.lower():
                    currency_name = curr
                    symbol = sym
                    break

        return {"currency": currency_name, "currency_symbol": symbol, "amount": amount}


ParserTypeCurrency = Annotated[
    dict[str, Optional[Union[str, float]]], BeforeValidator(CurrencyParser())
]

==> price_parser_reworkd-0.2.0-py3-none-any.whl: price_parser/parser.py <==
from pydantic import BeforeValidator
from typing import Union, Optional
from typing_extensions import Annotated
from price_parser.type_price import ParserTypePrice
from price_parser.constants import all_currencies, price_not_available_phrases


class CurrencyParser:
    @staticmethod
    def parse_currency_amount(
        value: Union[str, float, int, None],
    ) -> Union[float, None]:
        return ParserTypePrice.validate_price(value)

    def __call__(
        self, value: Union[str, float, int, None]
    ) -> dict[str, Optional[Union[str, float]]]:
        if isinstance(value, (float, int)):
            return {"currency": None, "currency_symbol": None, "amount": float(value)}
        symbol = None
        currency_name = None
        amount = None
        if value is not None:
            value = str(value).strip()
            if value.lower() in price_not_available_phrases:
                return {"currency": None, "currency_symbol": None, "amount": None}
            for sym, curr in all_currencies:
                if sym in value or curr.lower() in value.lower():
                    currency_name = curr
                    symbol = sym
                    break
            value = value.replace(symbol, "").strip() if symbol else value
            amount = self.parse_currency_amount(value)

        return {"currency": currency_name, "currency_symbol": symbol, "amount": amount}


ParserTypeCurrency = Annotated[
    dict[str, Optional[Union[str, float]]], BeforeValidator(CurrencyParser())
]
